Crate typst_bundle

Crate typst_bundle 

Multi-file output for Typst.

Structs

Bundle
A collection of files resulting from compilation.
BundleOptions
Settings for bundle export.
PagedExtras
Extra data relevant for exporting a paged document in a bundle.

Enums

BundleDocument
A document in one of the supported output formats, resulting from a document element.
BundleFile
A single file in the bundle.

Functions

bundle
Produces a bundle from content.
export
Exports a bundle into a raw virtual file system.

Type Aliases

VirtualFs
A raw mapping from paths to bytes.