pub fn export(
bundle: &Bundle,
options: &BundleOptions,
) -> SourceResult<VirtualFs>Expand description
Exports a bundle into a raw virtual file system.
pub fn export(
bundle: &Bundle,
options: &BundleOptions,
) -> SourceResult<VirtualFs>Exports a bundle into a raw virtual file system.