pub struct Bundle {
pub files: Arc<IndexMap<VirtualPath, BundleFile, FxBuildHasher>>,
pub introspector: Arc<BundleIntrospector>,
}Expand description
A collection of files resulting from compilation.
In the bundle target, Typst can emit multiple documents and assets from a
single Typst project.
The Bundle is the output of compilation and is to the bundle output
format what the PagedDocument is to pdf, png, and svg outputs.
Fields
files: Arc<IndexMap<VirtualPath, BundleFile, FxBuildHasher>>The files in the bundle.
introspector: Arc<BundleIntrospector>An introspector for the whole bundle.
The whole bundle is subject to one large introspection loop (as opposed to each document iterating separately). They can introspect each other and all contribute to this one introspector.